import { purry } from "./purry";
export function isDeepEqual() {
    return purry(isDeepEqualImplementation, arguments);
}
function isDeepEqualImplementation(data, other) {
    if (data === other) {
        return true;
    }
    if (typeof data === "number" && typeof other === "number") {
        return data !== data && other !== other;
    }
    if (typeof data !== "object" || typeof other !== "object") {
        return false;
    }
    if (data === null || other === null) {
        return false;
    }
    if (Object.getPrototypeOf(data) !== Object.getPrototypeOf(other)) {
        return false;
    }
    if (Array.isArray(data)) {
        if (data.length !== other.length) {
            return false;
        }
        for (var i = 0; i < data.length; i++) {
            if (!isDeepEqualImplementation(data[i], other[i])) {
                return false;
            }
        }
        return true;
    }
    if (data instanceof Date) {
        return data.getTime() === other.getTime();
    }
    if (data instanceof RegExp) {
        return data.toString() === other.toString();
    }
    var keys = Object.keys(data);
    if (keys.length !== Object.keys(other).length) {
        return false;
    }
    for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
        var key = keys_1[_i];
        if (!Object.prototype.hasOwnProperty.call(other, key)) {
            return false;
        }
        if (!isDeepEqualImplementation(data[key], other[key])) {
            return false;
        }
    }
    return true;
}
